AvailableOffer

Struct AvailableOffer 

pub struct AvailableOffer {
    pub offer_level: Option<String>,
    pub name: Option<String>,
    pub id: Option<i64>,
    pub qualified_customers_complete: Option<bool>,
    pub country_offer_infos: Option<Vec<CountryOfferInfo>>,
    pub offer_type: Option<String>,
    pub max_account_age: Option<i32>,
    pub qualified_customer: Option<Vec<OfferCustomer>>,
    pub terms: Option<String>,
    pub show_special_offer_copy: Option<bool>,
    pub available: Option<i32>,
    pub description: Option<String>,
}
Available Offers to be distributed.

This type is not used in any activity, and only used as part of another schema.

Fields

offer_level: Option<String>

Level of this offer.

name: Option<String>

Name of the offer.

id: Option<i64>

ID of this offer.

qualified_customers_complete: Option<bool>

Whether or not the list of qualified customers is definitely complete.

country_offer_infos: Option<Vec<CountryOfferInfo>>

Offer info by country.

offer_type: Option<String>

Type of offer.

max_account_age: Option<i32>

The maximum age of an account [in days] to be eligible.

qualified_customer: Option<Vec<OfferCustomer>>

Customers who qualify for this offer.

terms: Option<String>

Terms of the offer.

show_special_offer_copy: Option<bool>

Should special text be shown on the offers page.

available: Option<i32>

The number of codes for this offer that are available for distribution.

description: Option<String>

Description of the offer.