pub struct CertificationExamStatus {
pub number_users_pass: Option<i32>,
pub type_: Option<String>,
}Expand description
Status for a Google Partners certification exam.
This type is not used in any activity, and only used as part of another schema.
Fields
number_users_pass: Option<i32>The number of people who have passed the certification exam.
type_: Option<String>The type of certification exam.