pub struct CountryOfferInfo {
pub offer_country_code: Option<String>,
pub spend_x_amount: Option<String>,
pub offer_type: Option<String>,
pub get_y_amount: Option<String>,
}Expand description
Offer info by country.
This type is not used in any activity, and only used as part of another schema.
Fields
offer_country_code: Option<String>Country code for which offer codes may be requested.
spend_x_amount: Option<String>(localized) Spend X amount for that country’s offer.
offer_type: Option<String>Type of offer country is eligible for.
get_y_amount: Option<String>(localized) Get Y amount for that country’s offer.