pub struct GetCompanyResponse {
pub response_metadata: Option<ResponseMetadata>,
pub company: Option<Company>,
}Expand description
Response message for GetCompany.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get companies (response)
Fields
response_metadata: Option<ResponseMetadata>Current response metadata.
company: Option<Company>The company.