Struct google_partners2::api::Lead[][src]

pub struct Lead {
    pub min_monthly_budget: Option<Money>,
    pub given_name: Option<String>,
    pub language_code: Option<String>,
    pub website_url: Option<String>,
    pub state: Option<String>,
    pub gps_motivations: Option<Vec<String>>,
    pub email: Option<String>,
    pub family_name: Option<String>,
    pub id: Option<String>,
    pub comments: Option<String>,
    pub phone_number: Option<String>,
    pub adwords_customer_id: Option<String>,
    pub create_time: Option<String>,
    pub marketing_opt_in: Option<bool>,
    pub type_: Option<String>,
}

A lead resource that represents an advertiser contact for a Company. These are usually generated via Google Partner Search (the advertiser portal).

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

min_monthly_budget: Option<Money>

The minimum monthly budget lead source is willing to spend.

given_name: Option<String>

First name of lead source.

language_code: Option<String>

Language code of the lead’s language preference, as defined by BCP 47 (IETF BCP 47, “Tags for Identifying Languages”).

website_url: Option<String>

Website URL of lead source.

state: Option<String>

The lead’s state in relation to the company.

gps_motivations: Option<Vec<String>>

List of reasons for using Google Partner Search and creating a lead.

email: Option<String>

Email address of lead source.

family_name: Option<String>

Last name of lead source.

id: Option<String>

ID of the lead.

comments: Option<String>

Comments lead source gave.

phone_number: Option<String>

Phone number of lead source.

adwords_customer_id: Option<String>

The AdWords Customer ID of the lead.

create_time: Option<String>

Timestamp of when this lead was created.

marketing_opt_in: Option<bool>

Whether or not the lead signed up for marketing emails

type_: Option<String>

Type of lead.