pub struct Location {
pub administrative_area: Option<String>,
pub locality: Option<String>,
pub lat_lng: Option<LatLng>,
pub region_code: Option<String>,
pub dependent_locality: Option<String>,
pub address: Option<String>,
pub postal_code: Option<String>,
pub sorting_code: Option<String>,
pub language_code: Option<String>,
pub address_line: Option<Vec<String>>,
}Expand description
A location with address and geographic coordinates. May optionally contain a detailed (multi-field) version of the address.
This type is not used in any activity, and only used as part of another schema.
Fields
administrative_area: Option<String>Top-level administrative subdivision of this country.
locality: Option<String>Generally refers to the city/town portion of an address.
lat_lng: Option<LatLng>The latitude and longitude of the location, in degrees.
region_code: Option<String>CLDR (Common Locale Data Repository) region code .
dependent_locality: Option<String>Dependent locality or sublocality. Used for UK dependent localities, or neighborhoods or boroughs in other locations.
address: Option<String>The single string version of the address.
postal_code: Option<String>Values are frequently alphanumeric.
sorting_code: Option<String>Use of this code is very country-specific, but will refer to a secondary classification code for sorting mail.
language_code: Option<String>Language code of the address. Should be in BCP 47 format.
address_line: Option<Vec<String>>The following address lines represent the most specific part of any address.