UserProfile

Struct UserProfile 

pub struct UserProfile {
Show 15 fields pub channels: Option<Vec<String>>, pub profile_public: Option<bool>, pub job_functions: Option<Vec<String>>, pub given_name: Option<String>, pub address: Option<Location>, pub industries: Option<Vec<String>>, pub email_opt_ins: Option<OptIns>, pub family_name: Option<String>, pub languages: Option<Vec<String>>, pub markets: Option<Vec<String>>, pub migrate_to_afa: Option<bool>, pub adwords_manager_account: Option<i64>, pub phone_number: Option<String>, pub primary_country_code: Option<String>, pub email_address: Option<String>,
}
The profile information of a Partners user.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

channels: Option<Vec<String>>

A list of ids representing which channels the user selected they were in.

profile_public: Option<bool>

Whether the user’s public profile is visible to anyone with the URL.

job_functions: Option<Vec<String>>

A list of ids represnting which job categories the user selected.

given_name: Option<String>

The user’s given name.

address: Option<Location>

The user’s mailing address, contains multiple fields.

industries: Option<Vec<String>>

A list of ids representing which industries the user selected.

email_opt_ins: Option<OptIns>

The list of opt-ins for the user, related to communication preferences.

family_name: Option<String>

The user’s family name.

languages: Option<Vec<String>>

The list of languages this user understands.

markets: Option<Vec<String>>

A list of ids representing which markets the user was interested in.

migrate_to_afa: Option<bool>

Whether or not to migrate the user’s exam data to Academy for Ads.

adwords_manager_account: Option<i64>

If the user has edit access to multiple accounts, the user can choose the preferred account and it is used when a personal account is needed. Can be empty.

phone_number: Option<String>

The user’s phone number.

primary_country_code: Option<String>

The user’s primary country, an ISO 2-character code.

email_address: Option<String>

The email address the user has selected on the Partners site as primary.