pub struct CompanyRelation {Show 19 fields
pub company_admin: Option<bool>,
pub address: Option<String>,
pub is_pending: Option<bool>,
pub creation_time: Option<DateTime<Utc>>,
pub primary_address: Option<Location>,
pub state: Option<String>,
pub name: Option<String>,
pub manager_account: Option<i64>,
pub segment: Option<Vec<String>>,
pub internal_company_id: Option<String>,
pub badge_tier: Option<String>,
pub specialization_status: Option<Vec<SpecializationStatus>>,
pub phone_number: Option<String>,
pub website: Option<String>,
pub primary_country_code: Option<String>,
pub company_id: Option<String>,
pub primary_language_code: Option<String>,
pub logo_url: Option<String>,
pub resolved_timestamp: Option<DateTime<Utc>>,
}Expand description
A CompanyRelation resource representing information about a user’s affiliation and standing with a company in Partners.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- create company relation users (request|response)
Fields
company_admin: Option<bool>Indicates if the user is an admin for this company.
address: Option<String>The primary address for this company.
is_pending: Option<bool>The flag that indicates if the company is pending verification.
creation_time: Option<DateTime<Utc>>The timestamp of when affiliation was requested. @OutputOnly
primary_address: Option<Location>The primary location of the company.
state: Option<String>The state of relationship, in terms of approvals.
name: Option<String>The name (in the company’s primary language) for the company.
manager_account: Option<i64>The AdWords manager account # associated this company.
segment: Option<Vec<String>>The segment the company is classified as.
internal_company_id: Option<String>The internal company ID. Only available for a whitelisted set of api clients.
badge_tier: Option<String>Whether the company is a Partner.
specialization_status: Option<Vec<SpecializationStatus>>The list of Google Partners specialization statuses for the company.
phone_number: Option<String>The phone number for the company’s primary address.
website: Option<String>The website URL for this company.
primary_country_code: Option<String>The primary country code of the company.
company_id: Option<String>The ID of the company. There may be no id if this is a pending company.5
primary_language_code: Option<String>The primary language code of the company.
logo_url: Option<String>A URL to a profile photo, e.g. a G+ profile photo.
resolved_timestamp: Option<DateTime<Utc>>The timestamp when the user was approved. @OutputOnly